@@ -33,8 +33,14 @@ class APIException(WaifuException):
             message: The response message.
         """
         super().__init__(f'{status} {reason}: {errormessage}')
+        self.status=status
+        self.reason=reason
+        self.errormessage=errormessage
+        
 
 class NoToken(WaifuException):
     """Exception raised when the user try to request the gallery route with no token"""
     def __init__(self,message=f'You tried to request the gallery route with no token. Please pass your token to HoriAioClient'):
         super().__init__(message)
+        self.message=message
+        
